#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prelude-extras
version:              0.4.0.3
visibility:           public
id:                   prelude-extras-0.4.0.3-FCoSOtTiikDD8Es4OHTqgy
key:                  prelude-extras-0.4.0.3-FCoSOtTiikDD8Es4OHTqgy
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/prelude-extras
synopsis:             Higher order versions of Prelude classes
description:
    Higher order versions of Prelude classes to ease programming with polymorphic recursion and reduce UndecidableInstances

    See <http://flint.cs.yale.edu/trifonov/papers/sqcc.pdf> for further discussion of the approach taken here.

category:             Polymorphism, Combinators
abi:                  839ab3bab8199708201afa0362e3f22c
exposed:              True
exposed-modules:      Prelude.Extras
import-dirs:          /usr/lib/ghc-8.10.5/site-local/prelude-extras-0.4.0.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/prelude-extras-0.4.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/prelude-extras-0.4.0.3
hs-libraries:         HSprelude-extras-0.4.0.3-FCoSOtTiikDD8Es4OHTqgy
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-prelude-extras/html/prelude-extras.haddock

haddock-html:         /usr/share/doc/haskell-prelude-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

